Functions and Lists Mixed-Up Code Questions
--------------------------------------------

.. selectquestion:: functions_lists_mixedupcode_1_sq
   :fromid: functions_lists_mixedupcode_1, functions_lists_mixedupcode_1_ac
   :toggle: 


.. selectquestion:: functions_lists_mixedupcode_2_sq
   :fromid: functions_lists_mixedupcode_2, functions_lists_mixedupcode_2_ac
   :toggle: 


.. selectquestion:: functions_lists_mixedupcode_3_sq
   :fromid: functions_lists_mixedupcode_3, functions_lists_mixedupcode_3_ac
   :toggle: 


.. selectquestion:: functions_lists_mixedupcode_4_sq
   :fromid: functions_lists_mixedupcode_4, functions_lists_mixedupcode_4_ac
   :toggle: 


.. selectquestion:: functions_lists_mixedupcode_5_sq
   :fromid: functions_lists_mixedupcode_5, functions_lists_mixedupcode_5_ac
   :toggle: 